% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cc_dupl.R
\name{cc_dupl}
\alias{cc_dupl}
\title{Identify Duplicated Records}
\usage{
cc_dupl(x, lon = "decimallongitude", lat = "decimallatitude",
  species = "species", additions = NULL, value = "clean",
  verbose = TRUE)
}
\arguments{
\item{x}{data.frame. Containing geographical coordinates and species
names.}

\item{lon}{character string. The column with the longitude coordinates.
Default = \dQuote{decimallongitude}.}

\item{lat}{character string. The column with the latitude coordinates.
Default = \dQuote{decimallatitude}.}

\item{species}{a character string. The column with the species name. Default
= \dQuote{species}.}

\item{additions}{a vector of character strings. Additional columns to be
included in the test for duplication. For example as below, collector name
and collector number.}

\item{value}{character string.  Defining the output value. See value.}

\item{verbose}{logical. If TRUE reports the name of the test and the number
of records flagged.}
}
\value{
Depending on the \sQuote{value} argument, either a \code{data.frame}
containing the records considered correct by the test (\dQuote{clean}) or a
logical vector (\dQuote{flagged}), with TRUE = test passed and FALSE = test failed/potentially
problematic . Default = \dQuote{clean}.
}
\description{
Removes or flags duplicated records based on species name and coordinates, as well as
user-defined additional columns. True (specimen) duplicates or duplicates
from the same species can make up the bulk of records in a biological
collection database, but are undesirable for many analyses. Both can be
flagged with this function, the former given enough additional information.
}
\note{
See \url{https://ropensci.github.io/CoordinateCleaner} for more
details and tutorials.
}
\examples{

x <- data.frame(species = letters[1:10], 
                decimallongitude = sample(x = 0:10, size = 100, replace = TRUE), 
                decimallatitude = sample(x = 0:10, size = 100, replace = TRUE),
                collector = "Bonpl",
                collector.number = c(1001, 354),
                collection = rep(c("K", "WAG","FR", "P", "S"), 20))

cc_dupl(x, value = "flagged")
cc_dupl(x, additions = c("collector", "collector.number"))

}
\seealso{
Other Coordinates: \code{\link{cc_cap}},
  \code{\link{cc_cen}}, \code{\link{cc_coun}},
  \code{\link{cc_equ}}, \code{\link{cc_gbif}},
  \code{\link{cc_inst}}, \code{\link{cc_iucn}},
  \code{\link{cc_outl}}, \code{\link{cc_sea}},
  \code{\link{cc_urb}}, \code{\link{cc_val}},
  \code{\link{cc_zero}}
}
\concept{Coordinates}
\keyword{Coordinate}
\keyword{cleaning}
